from __future__ import print_function
import argparse
import time
from dash_import.import_factory import ImportFactory
import sys
import configuration

def diet_main():
    parser = argparse.ArgumentParser(description='Dash Import and Export Tool')

    parser.add_argument('direction', choices=['import', 'export'], type=str,
                        help='Action to perform')
    parser.add_argument('target', type=str,
                        help='The target of the import/export')
    parser.add_argument('files', metavar='file', type=file, nargs='+',
                        help='Files to import')

    args = parser.parse_args()

    config = configuration.DietConfiguration.load_from_home_dir()

    if args.direction == 'import':
        importer = ImportFactory().get_importer(target=args.target, configuration=config)

        if importer is None:
            print('Invalid target given')
            sys.exit(1)
        else:
            for import_file in args.files:
                importer.import_from_file(file=import_file)
                import_file.close()
    elif args.direction == 'export':
        print("Export has not been implemented yet")



import user
import user_org
from ..client_factory import ClientFactory

class ImportFactory(object):

    def get_importer(self, target, configuration):
        if target == 'user':
            return user.User(ClientFactory(configuration))
        if target == 'user-org':
            return user_org.UserOrg(ClientFactory(configuration))
        else:
            return None


import json
from os.path import expanduser, join

class DietConfiguration(object):

    def __init__(self, auth_client_id, auth_client_secret,
                 api_client_id, api_client_secret,
                 auth_verify_ssl, auth_host,
                 api_verify_ssl, api_host):
        self.auth_client_id = auth_client_id
        self.auth_client_secret = auth_client_secret
        self.api_client_id = api_client_id
        self.api_client_secret = api_client_secret
        self.auth_verify_ssl = auth_verify_ssl
        self.auth_host = auth_host
        self.api_verify_ssl = api_verify_ssl
        self.api_host = api_host

    @staticmethod
    def load_from_home_dir():
        home = expanduser('~')
        with open(join(home, '.diet', 'config.json')) as config_file:
            config = json.load(config_file)
            auth_client_id = config["auth"]["client_id"]
            auth_client_secret = config["auth"]["client_secret"]
            auth_host = config["auth"]["host"]
            auth_verify_ssl = config["auth"]["verify_ssl"]
            api_client_id = config["api"]["client_id"]
            api_client_secret = config["api"]["client_secret"]
            api_host = config["api"]["host"]
            api_verify_ssl = config["api"]["verify_ssl"]

            return DietConfiguration(auth_client_id=auth_client_id,
                auth_client_secret=auth_client_secret, api_client_id=api_client_id,
                api_client_secret=api_client_secret, auth_verify_ssl=auth_verify_ssl,
                auth_host=auth_host, api_host=api_host, api_verify_ssl=api_verify_ssl)


from dash_auth import Configuration as AuthConfig, ApiClient as AuthClient
from dash_api import Configuration as ApiConfig, ApiClient as AppClient
from requests_oauthlib import OAuth2Session
from oauthlib.oauth2 import BackendApplicationClient

class ClientFactory(object):

    def __init__(self, configuration):
        self.configuration = configuration
        self.auth_access_token = None
        self.app_access_token = None

    def get_auth_api_client(self):
        if self.auth_access_token is None:
            self.auth_access_token = self.get_access_token(self.configuration.auth_client_id,
                                                    self.configuration.auth_client_secret)

        auth_config = AuthConfig()
        auth_config.access_token = self.auth_access_token
        auth_config.host = self.configuration.auth_host
        auth_config.verify_ssl = self.configuration.auth_verify_ssl
        auth_api_client = AuthClient(configuration=auth_config)
        return auth_api_client

    def get_app_api_client(self,):
        if self.app_access_token is None:
            self.app_access_token = self.get_access_token(self.configuration.api_client_id,
                                                    self.configuration.api_client_secret)
        api_config = ApiConfig()
        api_config.access_token = self.app_access_token
        api_config.host = self.configuration.api_host
        api_config.verify_ssl = self.configuration.api_verify_ssl
        app_api_client = AppClient(configuration=api_config)
        return app_api_client

    def get_access_token(self, client_id, client_secret):
        token_url = "{host}/connect/token".format(host=self.configuration.auth_host)
        client = BackendApplicationClient(client_id=client_id)
        oauth = OAuth2Session(client=client)
        token = oauth.fetch_token(token_url=token_url, client_id=client_id,
                                client_secret=client_secret,
                                verify=self.configuration.auth_verify_ssl)

        return token['access_token']


import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

REQUIRES = ["dash-api-python-client", "dash-auth-python-client", "requests_oauthlib"]

setuptools.setup(
    name="diet",
    version="0.1.8",
    author="Alexander Burgett",
    author_email="alex.burgett@sprga.com.au",
    description="Dash Import Export Tool",
    long_description=long_description,
    long_description_content_type="text/markdown",
    install_requires=REQUIRES,
    packages=setuptools.find_packages(),
    entry_points={'console_scripts': ['diet = diet.__main__:main']},
    url="https://bitbucket.org/sporga/diet",
    classifiers=(
        "Programming Language :: Python :: 2",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ),
)